@@ -5,6 +5,8 @@ LINUX_PATH = '/etc/ssl/certs/ca-certificates.crt'
 # openssl installed using `brew install openssl`
 OSX_PATH = '/usr/local/etc/openssl/cert.pem'
 
+CUSTOM_SSL_CERT_PATH = os.getenv('UPWORK_SSL_CERT', '')
+
 
 def get():
     """Return a path to a certificate authority file.
@@ -18,6 +20,9 @@ def get():
     if os.path.exists(OSX_PATH):
         return OSX_PATH
 
+    if CUSTOM_SSL_CERT_PATH and os.path.exists(CUSTOM_SSL_CERT_PATH):
+        return CUSTOM_SSL_CERT_PATH
+
     # Fall back to the httplib2 default behavior by raising an
     # ImportError if we have not found the file.
     raise ImportError()
